@@ -7,7 +7,7 @@ import itertools
 from copy import deepcopy
 from blinker import signal
 import messages as messages
-import shelve 
+import shelve
 
 
 """
@@ -58,7 +58,7 @@ class Parser(object):
             print messages.file_decode_error % (source_file)
             traceback.print_exc()
         return file_contents
-    
+
     def parse(self, filepath, file_name, relative_path,  file_contents, mtime):
         page_data = {"data":[]}
         contents = self.attempt(file_contents, filepath)
@@ -68,8 +68,8 @@ class Parser(object):
 
         _defaults = deepcopy(self.defaults)
         page_data.update(_defaults)
-        
-        if contents != None: 
+
+        if contents != None:
             if "meta" in contents:
                 page_data["meta"].update(contents["meta"])
             if "data" in contents:
@@ -84,13 +84,13 @@ class Parser(object):
 
         sig = signal("wranglerLoadItem")
         sig.send('item', item=file_name, file_contents=file_contents, mtime=mtime)
-        
+
         return page_data
 
     def load(self, filepath):
         file_name, file_extension = os.path.splitext(filepath)
         file_path = os.path.join(self.project_root, filepath)
-        relative_path = file_name.replace(self.input_dir+"/", "")     
+        relative_path = file_name.replace(self.input_dir+"/", "")
         mtime = os.path.getmtime(filepath)
         file_contents = self.read(file_path)
 
@@ -176,7 +176,7 @@ class Node(object):
         siblings = []
         if self.parent != None:
             siblings = [sibling for sibling in  self.get_parent().get_children() if sibling.path != self.path]
-        return siblings 
+        return siblings
 
     def get_child(self, name):
         child = None
@@ -185,7 +185,7 @@ class Node(object):
             if name == "index" and item.is_index:
                 child = item
             elif item.name == name:
-                child = item  
+                child = item
 
         return child
 
@@ -193,7 +193,7 @@ class Node(object):
         children = []
 
         directories = [d for d in self.get_parent().get_children() if d.tag == 'dir']
-        
+
         for node in directories:
             index = node.get_child("index")
 
@@ -225,7 +225,7 @@ class Node(object):
         _get(self.parent)
 
         return parents
-    
+
 
     def get_parents_siblings(self):
         _parent_siblings = []
@@ -236,7 +236,7 @@ class Node(object):
             parent = self.get_parent().get_parent()
 
         if parent:
-            directories = [d for d in parent.get_children() if d.tag == 'dir'] 
+            directories = [d for d in parent.get_children() if d.tag == 'dir']
 
             for node in directories:
                 index = node.get_child("index")
@@ -272,11 +272,11 @@ class Page(object):
 
     def get_file_ext(self):
         return self.data["meta"]["output_file_extension"] if "output_file_extension" in self.data["meta"] else None
-    
+
     def set_name(self, filepath):
         self.name = os.path.splitext(filepath)[0]
         return self.name
-    
+
     def get_name(self):
         return self.name
 
@@ -294,7 +294,7 @@ class Page(object):
 
     def get_output_path(self):
         file_ext = self.get_file_ext()
-        
+
         if file_ext == None:
             return self.output_path
         else:
@@ -307,7 +307,7 @@ class Page(object):
         self.output_path = path[0]
         self.relative_output_path = path[1]
         self.output_path_no_ext = path[2]
-        
+
         self._ext = self.output_path.split(".")[1]
         tidy_url = self.relative_output_path.replace("index.%s" % (self._ext), "")
 
@@ -354,6 +354,9 @@ class Page(object):
     def show_in_navigation(self):
         return False if "hide_from_nav" in self.data["meta"] and self.data["meta"]["hide_from_nav"] else True
 
+    def ignore_output(self):
+        return True if "ignore_output" in self.data["meta"] and self.data["meta"]["ignore_output"] == True else False
+
     def get_weight(self):
         return self.data["meta"]["weight"] if "weight" in self.data["meta"] else 0
 
@@ -373,13 +376,13 @@ class Page(object):
 
     def map_related_nodes(self, nodes, keyname):
         _data = []
-        
+
         for node in nodes:
             if node:
                 page = node.get_cargo()
                 if page != None:
                     _data.append(page.get_properties())
-        
+
         self.data["meta"][keyname] = _data
 
     def set_siblings(self, nodes):
@@ -454,11 +457,16 @@ class Writer(object):
 
         filename = item.get_output_path()
         new_directory = os.path.dirname(filename)
+        should_ignore =  item.ignore_output()
+
+        if should_ignore:
+            return False;
 
         if html == False:
             return False
 
-        try: 
+
+        try:
             sig = signal('wranglerBeforeSaveItem')
             sig.send('item', item=item, path=filename)
             util.ensure_dir(new_directory)
@@ -509,7 +517,7 @@ class Reporter(object):
             print>>file, "%s, %s, %s" % (item[0], item[2], item[1])
 
         self.verbose(messages.write_log % (self.config['compiled_templates_log']))
-    
+
     def log_item_saved(self, path, template, result):
         self.log_data.append([path, template, result])
 
@@ -559,8 +567,8 @@ class Reporter(object):
             "blue": "\033[34m",
             "basic": "\033[0m"
         }
-        
-        return "%s%s%s" % (colours[colour], message, colours["basic"]) 
+
+        return "%s%s%s" % (colours[colour], message, colours["basic"])
 
     def log(self, message, status=None):
         msg = message
